spannertools.get_spanners_that_dominate_components
==================================================

.. autofunction:: abjad.tools.spannertools.get_spanners_that_dominate_components.get_spanners_that_dominate_components
